Module table

Module table 

Table

Functions

generate_table_string_vec
This is a utility function used to convert raw 2-D Vectors of strings into a formatter vector of strings that represents table structure.