generate_table_string_vec

Function generate_table_string_vec 

pub fn generate_table_string_vec<S>(
    rows: Vec<Vec<S>>,
    options: Option<TableOptions>,
) -> Vec<String>
where S: Into<String>,
This is a utility function used to convert raw 2-D Vectors of strings into a formatter vector of strings that represents table structure.